@@ -28,7 +28,7 @@
 #include "flatpak-progress-private.h"
 #include "flatpak-variant-private.h"
 #include "flatpak-ref-utils-private.h"
-#include "libglnx/libglnx.h"
+#include "libglnx.h"
 
 /* Version history:
  * The version field was added in flatpak 1.2, anything before is 0.
@@ -70,6 +70,7 @@ GType flatpak_deploy_get_type (void);
 #define FLATPAK_REF_BRANCH_KEY "Branch"
 #define FLATPAK_REF_COLLECTION_ID_KEY "CollectionID"
 #define FLATPAK_REF_DEPLOY_COLLECTION_ID_KEY "DeployCollectionID"
+#define FLATPAK_REF_DEPLOY_SIDELOAD_COLLECTION_ID_KEY "DeploySideloadCollectionID"
 
 #define FLATPAK_REPO_GROUP "Flatpak Repo"
 #define FLATPAK_REPO_VERSION_KEY "Version"
@@ -89,6 +90,7 @@ GType flatpak_deploy_get_type (void);
 
 #define FLATPAK_REPO_COLLECTION_ID_KEY "CollectionID"
 #define FLATPAK_REPO_DEPLOY_COLLECTION_ID_KEY "DeployCollectionID"
+#define FLATPAK_REPO_DEPLOY_SIDELOAD_COLLECTION_ID_KEY "DeploySideloadCollectionID"
 
 #define FLATPAK_CLI_UPDATE_INTERVAL_MS 300
 
@@ -198,8 +200,8 @@ GVariant *flatpak_remote_state_load_ref_commit (FlatpakRemoteState *self,
                                                 char              **out_commit,
                                                 GCancellable       *cancellable,
                                                 GError            **error);
-void flatpak_remote_state_add_sideload_repo (FlatpakRemoteState *self,
-                                             GFile               *path);
+void flatpak_remote_state_add_sideload_dir (FlatpakRemoteState *self,
+                                            GFile              *path);
 
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (FlatpakDir, g_object_unref)
@@ -646,10 +648,19 @@ GPtrArray *           flatpak_dir_list_refs                                 (Fla
                                                                              FlatpakKinds                   kinds,
                                                                              GCancellable                  *cancellable,
                                                                              GError                       **error);
+gboolean              flatpak_dir_is_runtime_extension                      (FlatpakDir                    *self,
+                                                                             FlatpakDecomposed             *ref);
 GPtrArray *           flatpak_dir_list_app_refs_with_runtime                (FlatpakDir                    *self,
+                                                                             GHashTable                   **runtime_app_map,
                                                                              FlatpakDecomposed             *runtime_ref,
                                                                              GCancellable                  *cancellable,
                                                                              GError                       **error);
+GPtrArray *           flatpak_dir_list_app_refs_with_runtime_extension      (FlatpakDir                    *self,
+                                                                             GHashTable                   **runtime_app_map,
+                                                                             GHashTable                   **extension_app_map,
+                                                                             FlatpakDecomposed             *runtime_ext_ref,
+                                                                             GCancellable                  *cancellable,
+                                                                             GError                       **error);
 GVariant *            flatpak_dir_read_latest_commit                        (FlatpakDir                    *self,
                                                                              const char                    *remote,
                                                                              FlatpakDecomposed             *ref,
